@@ -2,14 +2,10 @@ import _plotly_utils.basevalidators
 
 
 class VisibleValidator(_plotly_utils.basevalidators.BooleanValidator):
-
-    def __init__(
-        self, plotly_name='visible', parent_name='layout.shape', **kwargs
-    ):
+    def __init__(self, plotly_name="visible", parent_name="layout.shape", **kwargs):
         super(VisibleValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'calc+arraydraw'),
-            role=kwargs.pop('role', 'info'),
-            **kwargs
+            edit_type=kwargs.pop("edit_type", "calc+arraydraw"),
+            **kwargs,
         )
