@@ -2,17 +2,15 @@ import _plotly_utils.basevalidators
 
 
 class OutlinecolorValidator(_plotly_utils.basevalidators.ColorValidator):
-
     def __init__(
         self,
-        plotly_name='outlinecolor',
-        parent_name='scatter.marker.colorbar',
-        **kwargs
+        plotly_name="outlinecolor",
+        parent_name="scatter.marker.colorbar",
+        **kwargs,
     ):
         super(OutlinecolorValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'colorbars'),
-            role=kwargs.pop('role', 'style'),
-            **kwargs
+            edit_type=kwargs.pop("edit_type", "colorbars"),
+            **kwargs,
         )
