@@ -2,17 +2,12 @@ import _plotly_utils.basevalidators
 
 
 class NamelengthsrcValidator(_plotly_utils.basevalidators.SrcValidator):
-
     def __init__(
-        self,
-        plotly_name='namelengthsrc',
-        parent_name='scatter3d.hoverlabel',
-        **kwargs
+        self, plotly_name="namelengthsrc", parent_name="scatter3d.hoverlabel", **kwargs
     ):
         super(NamelengthsrcValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'none'),
-            role=kwargs.pop('role', 'info'),
-            **kwargs
+            edit_type=kwargs.pop("edit_type", "none"),
+            **kwargs,
         )
